#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Python Hadoop Pig
# 
# This notebook aims at showing how to submit a PIG job to remote hadoop cluster (tested with Cloudera). It works better if you know Hadoop otherwise I recommend reading [Map/Reduce avec PIG](http://www.xavierdupre.fr/app/ensae_teaching_cs/helpsphinx2/notebooks/td3a_cenonce_session6.html#td3acenoncesession6rst) (French). First, we download data. We are going to upload that data to the remote cluster. The Hadoop distribution tested here is [Cloudera](http://www.cloudera.com/).

# In[1]:


import pyensae
get_ipython().run_line_magic('load_ext', 'pyensae')
get_ipython().run_line_magic('load_ext', 'pyenbc')
pyensae.download_data("ConfLongDemo_JSI.txt", website="https://archive.ics.uci.edu/ml/machine-learning-databases/00196/")


# We open a SSH connection to the bridge which can communicate to the cluster.

# In[2]:


import pyquickhelper.ipythonhelper as ipy
params={"server":"", "username":"", "password":""}
ipy.open_html_form(params=params,title="credentials",key_save="ssh_remote_hadoop")


# In[3]:


password = ssh_remote_hadoop["password"]
server = ssh_remote_hadoop["server"]
username = ssh_remote_hadoop["username"]


# We open the SSH connection:

# In[4]:


get_ipython().run_line_magic('remote_open', '')


# We check  the content of the remote machine:

# In[5]:


get_ipython().run_line_magic('remote_cmd', 'ls -l')


# In[6]:


get_ipython().run_line_magic('remote_ls', '.')


# We check the content on the cluster:

# In[7]:


get_ipython().run_line_magic('remote_cmd', 'hdfs dfs -ls')


# In[8]:


get_ipython().run_line_magic('dfs_ls', '.')


# We upload the file on the bridge (we should zip it first, it would reduce the uploading time).

# In[9]:


get_ipython().run_line_magic('remote_up', 'ConfLongDemo_JSI.txt ConfLongDemo_JSI.txt')


# We check it got there:

# In[10]:


get_ipython().run_line_magic('remote_cmd', 'ls Conf*JSI.txt')


# We put it on the cluster:

# In[11]:


get_ipython().run_line_magic('remote_cmd', 'hdfs dfs -put ConfLongDemo_JSI.txt ConfLongDemo_JSI.txt')


# We check it was put on the cluster:

# In[12]:


get_ipython().run_line_magic('remote_cmd', 'hdfs dfs -ls Conf*JSI.txt')


# In[13]:


dfs_ls Conf*JSI.txt


# We create a simple PIG program:

# In[14]:


get_ipython().run_cell_magic('PIG', 'filter_example.pig', "\nmyinput = LOAD 'ConfLongDemo_JSI.txt' USING PigStorage(',') AS\n    (index:long, sequence, tag, timestamp:long, dateformat, x:double,y:double, z:double, activity) ;\nfilt = FILTER myinput BY activity == 'walking' ;\nSTORE filt INTO 'ConfLongDemo_JSI.walking.txt' USING PigStorage() ;\n")


# In[15]:


get_ipython().run_line_magic('pig_submit', 'filter_example.pig -r=filter_example.redirect')


# We check the redirected files were created:

# In[16]:


get_ipython().run_line_magic('remote_cmd', 'ls f*redirect*')


# We check the tail on a regular basis to see the job running (some other commands can be used to monitor jobs, ``%remote_cmd mapred --help``).

# In[17]:


get_ipython().run_line_magic('remote_cmd', 'tail filter_example.redirect.err')


# In[18]:


get_ipython().run_line_magic('remote_cmd', 'hdfs dfs -ls Conf*JSI.walking.txt')


# In[19]:


get_ipython().run_line_magic('dfs_ls', 'Conf*JSI.walking.txt')


# After that, the stream has to downloaded to the bridge and then to the local machine with ``%remote_down``. We finally close the connection.

# In[20]:


get_ipython().run_line_magic('remote_close', '')


# **END**

# In[21]: